# Django CRUD App


## Running the Application


Make sure you create the your DB using:

    ./manage.py migrate

or for Django < 1.7:

    ./manage.py syncdb 

Now you can run the development webs server:

    ./manage.py runserver 

To access the two applications go to the URL <http://localhost:8000/> 
